Coverage for appr/api/gevent_app.py: 58%

# Coverage for appr/api/gevent_app.py : 58%

## 12 statements 7 run 5 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 | #!/usr/bin/env python from __future__ import absolute_import, division, print_function import os from gevent.wsgi import WSGIServer from appr.api.app import create_app class GeventApp(object): def __init__(self, options=None): self.args_options = options or {} os.environ['APPR_DB_CLASS'] = self.args_options.db_class print("Listening %s:%s" % (self.args_options.bind, self.args_options.port)) self.http_server = WSGIServer((self.args_options.bind, self.args_options.port), create_app()) def run(self): self.http_server.serve_forever()